package javax.swing.plaf.synth;

import javax.swing.plaf.UIResource;
import java.awt.LayoutManager;
import java.awt.Component;
import javax.swing.text.View;
import java.awt.Font;
import sun.swing.SwingUtilities2;
import javax.swing.Icon;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseListener;
import java.beans.PropertyChangeEvent;
import javax.swing.BorderFactory;
import javax.swing.UIManager;
import javax.swing.JButton;
import java.awt.Insets;
import javax.swing.JTabbedPane;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Rectangle;
import java.beans.PropertyChangeListener;
import javax.swing.plaf.basic.BasicTabbedPaneUI;

public class SynthTabbedPaneUI extends BasicTabbedPaneUI implements PropertyChangeListener, SynthUI
{
    private int tabOverlap;
    private boolean extendTabsToBase;
    private SynthContext tabAreaContext;
    private SynthContext tabContext;
    private SynthContext tabContentContext;
    private SynthStyle style;
    private SynthStyle tabStyle;
    private SynthStyle tabAreaStyle;
    private SynthStyle tabContentStyle;
    private Rectangle textRect;
    private Rectangle iconRect;
    private Rectangle tabAreaBounds;
    private boolean tabAreaStatesMatchSelectedTab;
    private boolean nudgeSelectedLabel;
    private boolean selectedTabIsPressed;
    
    public SynthTabbedPaneUI() {
        this.tabOverlap = 0;
        this.extendTabsToBase = false;
        this.textRect = new Rectangle();
        this.iconRect = new Rectangle();
        this.tabAreaBounds = new Rectangle();
        this.tabAreaStatesMatchSelectedTab = false;
        this.nudgeSelectedLabel = true;
        this.selectedTabIsPressed = false;
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthTabbedPaneUI();
    }
    
    private boolean scrollableTabLayoutEnabled() {
        return this.tabPane.getTabLayoutPolicy() == 1;
    }
    
    @Override
    protected void installDefaults() {
        this.updateStyle(this.tabPane);
    }
    
    private void updateStyle(JTabbedPane tabbedPane) {
        SynthContext context = this.getContext(tabbedPane, 1);
        SynthStyle style = this.style;
        this.style = SynthLookAndFeel.updateStyle(context, this);
        if (this.style != style) {
            this.tabRunOverlay = this.style.getInt(context, "TabbedPane.tabRunOverlay", 0);
            this.tabOverlap = this.style.getInt(context, "TabbedPane.tabOverlap", 0);
            this.extendTabsToBase = this.style.getBoolean(context, "TabbedPane.extendTabsToBase", false);
            this.textIconGap = this.style.getInt(context, "TabbedPane.textIconGap", 0);
            this.selectedTabPadInsets = (Insets)this.style.get(context, "TabbedPane.selectedTabPadInsets");
            if (this.selectedTabPadInsets == null) {
                this.selectedTabPadInsets = new Insets(0, 0, 0, 0);
            }
            this.tabAreaStatesMatchSelectedTab = this.style.getBoolean(context, "TabbedPane.tabAreaStatesMatchSelectedTab", false);
            this.nudgeSelectedLabel = this.style.getBoolean(context, "TabbedPane.nudgeSelectedLabel", true);
            if (style != null) {
                this.uninstallKeyboardActions();
                this.installKeyboardActions();
            }
        }
        context.dispose();
        if (this.tabContext != null) {
            this.tabContext.dispose();
        }
        this.tabContext = this.getContext(tabbedPane, Region.TABBED_PANE_TAB, 1);
        this.tabStyle = SynthLookAndFeel.updateStyle(this.tabContext, this);
        this.tabInsets = this.tabStyle.getInsets(this.tabContext, null);
        if (this.tabAreaContext != null) {
            this.tabAreaContext.dispose();
        }
        this.tabAreaContext = this.getContext(tabbedPane, Region.TABBED_PANE_TAB_AREA, 1);
        this.tabAreaStyle = SynthLookAndFeel.updateStyle(this.tabAreaContext, this);
        this.tabAreaInsets = this.tabAreaStyle.getInsets(this.tabAreaContext, null);
        if (this.tabContentContext != null) {
            this.tabContentContext.dispose();
        }
        this.tabContentContext = this.getContext(tabbedPane, Region.TABBED_PANE_CONTENT, 1);
        this.tabContentStyle = SynthLookAndFeel.updateStyle(this.tabContentContext, this);
        this.contentBorderInsets = this.tabContentStyle.getInsets(this.tabContentContext, null);
    }
    
    @Override
    protected void installListeners() {
        super.installListeners();
        this.tabPane.addPropertyChangeListener(this);
    }
    
    @Override
    protected void uninstallListeners() {
        super.uninstallListeners();
        this.tabPane.removePropertyChangeListener(this);
    }
    
    @Override
    protected void uninstallDefaults() {
        SynthContext context = this.getContext(this.tabPane, 1);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
        this.tabStyle.uninstallDefaults(this.tabContext);
        this.tabContext.dispose();
        this.tabContext = null;
        this.tabStyle = null;
        this.tabAreaStyle.uninstallDefaults(this.tabAreaContext);
        this.tabAreaContext.dispose();
        this.tabAreaContext = null;
        this.tabAreaStyle = null;
        this.tabContentStyle.uninstallDefaults(this.tabContentContext);
        this.tabContentContext.dispose();
        this.tabContentContext = null;
        this.tabContentStyle = null;
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, SynthLookAndFeel.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    private SynthContext getContext(JComponent component, Region region, int n) {
        SynthStyle synthStyle = null;
        if (region == Region.TABBED_PANE_TAB) {
            synthStyle = this.tabStyle;
        }
        else if (region == Region.TABBED_PANE_TAB_AREA) {
            synthStyle = this.tabAreaStyle;
        }
        else if (region == Region.TABBED_PANE_CONTENT) {
            synthStyle = this.tabContentStyle;
        }
        return SynthContext.getContext(component, region, synthStyle, n);
    }
    
    @Override
    protected JButton createScrollButton(int direction) {
        if (UIManager.getBoolean("TabbedPane.useBasicArrows")) {
            JButton scrollButton = super.createScrollButton(direction);
            scrollButton.setBorder(BorderFactory.createEmptyBorder());
            return scrollButton;
        }
        return new SynthTabbedPaneUI.SynthScrollableTabButton(direction);
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        if (SynthLookAndFeel.shouldUpdateStyle(propertyChangeEvent)) {
            this.updateStyle(this.tabPane);
        }
    }
    
    @Override
    protected MouseListener createMouseListener() {
        final MouseListener mouseListener = super.createMouseListener();
        return new MouseListener() {
            
            @Override
            public void mouseClicked(MouseEvent mouseEvent) {
                mouseListener.mouseClicked(mouseEvent);
            }
            
            @Override
            public void mouseEntered(MouseEvent mouseEvent) {
                mouseListener.mouseEntered(mouseEvent);
            }
            
            @Override
            public void mouseExited(MouseEvent mouseEvent) {
                mouseListener.mouseExited(mouseEvent);
            }
            
            @Override
            public void mousePressed(MouseEvent mouseEvent) {
                if (!SynthTabbedPaneUI.this.tabPane.isEnabled()) {
                    return;
                }
                int tabForCoordinate = SynthTabbedPaneUI.this.tabForCoordinate(SynthTabbedPaneUI.this.tabPane, mouseEvent.getX(), mouseEvent.getY());
                if (tabForCoordinate >= 0 && SynthTabbedPaneUI.this.tabPane.isEnabledAt(tabForCoordinate) && tabForCoordinate == SynthTabbedPaneUI.this.tabPane.getSelectedIndex()) {
                    SynthTabbedPaneUI.this.selectedTabIsPressed = true;
                    SynthTabbedPaneUI.this.tabPane.repaint();
                }
                mouseListener.mousePressed(mouseEvent);
                return;
            }
            
            @Override
            public void mouseReleased(MouseEvent mouseEvent) {
                if (SynthTabbedPaneUI.this.selectedTabIsPressed) {
                    SynthTabbedPaneUI.this.selectedTabIsPressed = false;
                    SynthTabbedPaneUI.this.tabPane.repaint();
                }
                mouseListener.mouseReleased(mouseEvent);
                delegate2.mouseMoved(mouseEvent);
            }
        };
    }
    
    @Override
    protected int getTabLabelShiftX(int tabPlacement, int tabIndex, boolean isSelected) {
        if (this.nudgeSelectedLabel) {
            return super.getTabLabelShiftX(tabPlacement, tabIndex, isSelected);
        }
        return 0;
    }
    
    @Override
    protected int getTabLabelShiftY(int tabPlacement, int tabIndex, boolean isSelected) {
        if (this.nudgeSelectedLabel) {
            return super.getTabLabelShiftY(tabPlacement, tabIndex, isSelected);
        }
        return 0;
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        context.getPainter().paintTabbedPaneBackground(context, graphics, 0, 0, component.getWidth(), component.getHeight());
        this.paint(context, graphics);
        context.dispose();
    }
    
    @Override
    protected int getBaseline(int tab) {
        if (this.tabPane.getTabComponentAt(tab) != null || this.getTextViewForTab(tab) != null) {
            return super.getBaseline(tab);
        }
        String title = this.tabPane.getTitleAt(tab);
        FontMetrics fontMetrics = this.getFontMetrics(this.tabContext.getStyle().getFont(this.tabContext));
        Icon iconForTab = this.getIconForTab(tab);
        this.textRect.setBounds(0, 0, 0, 0);
        this.iconRect.setBounds(0, 0, 0, 0);
        this.calcRect.setBounds(0, 0, 32767, this.maxTabHeight);
        this.tabContext.getStyle().getGraphicsUtils(this.tabContext).layoutText(this.tabContext, fontMetrics, title, iconForTab, 0, 0, 10, 0, this.calcRect, this.iconRect, this.textRect, this.textIconGap);
        return this.textRect.y + fontMetrics.getAscent() + this.getBaselineOffset();
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintTabbedPaneBorder(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics graphics) {
        int selectedIndex = this.tabPane.getSelectedIndex();
        int tabPlacement = this.tabPane.getTabPlacement();
        this.ensureCurrentLayout();
        if (!this.scrollableTabLayoutEnabled()) {
            Insets insets = this.tabPane.getInsets();
            int left = insets.left;
            int top = insets.top;
            int calculateTabAreaWidth = this.tabPane.getWidth() - insets.left - insets.right;
            int calculateTabAreaHeight = this.tabPane.getHeight() - insets.top - insets.bottom;
            switch (tabPlacement) {
                case 2: {
                    calculateTabAreaWidth = this.calculateTabAreaWidth(tabPlacement, this.runCount, this.maxTabWidth);
                    break;
                }
                case 4: {
                    int calculateTabAreaWidth2 = this.calculateTabAreaWidth(tabPlacement, this.runCount, this.maxTabWidth);
                    left = left + calculateTabAreaWidth - calculateTabAreaWidth2;
                    calculateTabAreaWidth = calculateTabAreaWidth2;
                    break;
                }
                case 3: {
                    int calculateTabAreaHeight2 = this.calculateTabAreaHeight(tabPlacement, this.runCount, this.maxTabHeight);
                    top = top + calculateTabAreaHeight - calculateTabAreaHeight2;
                    calculateTabAreaHeight = calculateTabAreaHeight2;
                    break;
                }
                default: {
                    calculateTabAreaHeight = this.calculateTabAreaHeight(tabPlacement, this.runCount, this.maxTabHeight);
                    break;
                }
            }
            this.tabAreaBounds.setBounds(left, top, calculateTabAreaWidth, calculateTabAreaHeight);
            if (graphics.getClipBounds().intersects(this.tabAreaBounds)) {
                this.paintTabArea(this.tabAreaContext, graphics, tabPlacement, selectedIndex, this.tabAreaBounds);
            }
        }
        this.paintContentBorder(this.tabContentContext, graphics, tabPlacement, selectedIndex);
    }
    
    @Override
    protected void paintTabArea(Graphics graphics, int n, int n2) {
        Insets insets = this.tabPane.getInsets();
        this.paintTabArea(this.tabAreaContext, graphics, n, n2, new Rectangle(insets.left, insets.top, this.tabPane.getWidth() - insets.left - insets.right, this.tabPane.getHeight() - insets.top - insets.bottom));
    }
    
    private void paintTabArea(SynthContext synthContext, Graphics graphics, int n, int n2, Rectangle rectangle) {
        Rectangle clipBounds = graphics.getClipBounds();
        if (this.tabAreaStatesMatchSelectedTab && n2 >= 0) {
            this.updateTabContext(n2, true, this.selectedTabIsPressed, this.getRolloverTab() == n2, this.getFocusIndex() == n2);
            synthContext.setComponentState(this.tabContext.getComponentState());
        }
        else {
            synthContext.setComponentState(1);
        }
        SynthLookAndFeel.updateSubregion(synthContext, graphics, rectangle);
        synthContext.getPainter().paintTabbedPaneTabAreaBackground(synthContext, graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height, n);
        synthContext.getPainter().paintTabbedPaneTabAreaBorder(synthContext, graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height, n);
        int tabCount = this.tabPane.getTabCount();
        this.iconRect.setBounds(0, 0, 0, 0);
        this.textRect.setBounds(0, 0, 0, 0);
        for (int i = this.runCount - 1; i >= 0; --i) {
            int j = this.tabRuns[i];
            int n3 = this.tabRuns[(i == this.runCount - 1) ? 0 : (i + 1)];
            int n4;
            for (n4 = ((n3 != 0) ? (n3 - 1) : (tabCount - 1)), ; j <= n4; ++j) {
                if (this.rects[j].intersects(clipBounds) && n2 != j) {
                    this.paintTab(this.tabContext, graphics, n, this.rects, j, this.iconRect, this.textRect);
                }
            }
        }
        if (n2 >= 0 && this.rects[n2].intersects(clipBounds)) {
            this.paintTab(this.tabContext, graphics, n, this.rects, n2, this.iconRect, this.textRect);
        }
    }
    
    @Override
    protected void setRolloverTab(int n) {
        int rolloverTab = this.getRolloverTab();
        super.setRolloverTab(n);
        if (rolloverTab != n && this.tabAreaStatesMatchSelectedTab) {
            this.tabPane.repaint();
        }
        else {
            if (rolloverTab >= 0 && rolloverTab < this.tabPane.getTabCount()) {
                Rectangle tabBounds = this.getTabBounds(this.tabPane, rolloverTab);
                if (tabBounds != null) {
                    this.tabPane.repaint(tabBounds);
                }
            }
            if (n >= 0) {
                Rectangle tabBounds2 = this.getTabBounds(this.tabPane, n);
                if (tabBounds2 != null) {
                    this.tabPane.repaint(tabBounds2);
                }
            }
        }
    }
    
    private void paintTab(SynthContext synthContext, Graphics graphics, int tabPlacement, Rectangle[] array, int n, Rectangle iconRect, Rectangle rectangle) {
        Rectangle rectangle2 = array[n];
        int selectedIndex = this.tabPane.getSelectedIndex();
        int isSelected = selectedIndex == n;
        this.updateTabContext(n, (boolean)isSelected, isSelected && this.selectedTabIsPressed, this.getRolloverTab() == n, this.getFocusIndex() == n);
        SynthLookAndFeel.updateSubregion(synthContext, graphics, rectangle2);
        int x = rectangle2.x;
        int y = rectangle2.y;
        int height = rectangle2.height;
        int width = rectangle2.width;
        int tabPlacement2 = this.tabPane.getTabPlacement();
        if (this.extendTabsToBase && this.runCount > 1 && selectedIndex >= 0) {
            Rectangle rectangle3 = array[selectedIndex];
            switch (tabPlacement2) {
                case 1: {
                    height = rectangle3.y + rectangle3.height - rectangle2.y;
                    break;
                }
                case 2: {
                    width = rectangle3.x + rectangle3.width - rectangle2.x;
                    break;
                }
                case 3: {
                    int y2 = rectangle3.y;
                    height = rectangle2.y + rectangle2.height - y2;
                    y = y2;
                    break;
                }
                case 4: {
                    int x2 = rectangle3.x;
                    width = rectangle2.x + rectangle2.width - x2;
                    x = x2;
                    break;
                }
            }
        }
        this.tabContext.getPainter().paintTabbedPaneTabBackground(this.tabContext, graphics, x, y, width, height, n, tabPlacement2);
        this.tabContext.getPainter().paintTabbedPaneTabBorder(this.tabContext, graphics, x, y, width, height, n, tabPlacement2);
        if (this.tabPane.getTabComponentAt(n) == null) {
            String title = this.tabPane.getTitleAt(n);
            Font font = synthContext.getStyle().getFont(synthContext);
            FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(this.tabPane, graphics, font);
            Icon iconForTab = this.getIconForTab(n);
            this.layoutLabel(synthContext, tabPlacement, fontMetrics, n, title, iconForTab, rectangle2, iconRect, rectangle, (boolean)isSelected);
            this.paintText(synthContext, graphics, tabPlacement, font, fontMetrics, n, title, rectangle, (boolean)isSelected);
            this.paintIcon(graphics, tabPlacement, n, iconForTab, iconRect, (boolean)isSelected);
        }
    }
    
    private void layoutLabel(SynthContext synthContext, int n, FontMetrics fontMetrics, int tabIndex, String s, Icon icon, Rectangle rectangle, Rectangle rectangle2, Rectangle rectangle3, boolean b) {
        View textViewForTab = this.getTextViewForTab(tabIndex);
        if (textViewForTab != null) {
            this.tabPane.putClientProperty("html", textViewForTab);
        }
        int n2 = 0;
        rectangle2.y = n2;
        rectangle2.x = n2;
        rectangle3.y = n2;
        rectangle3.x = n2;
        synthContext.getStyle().getGraphicsUtils(synthContext).layoutText(synthContext, fontMetrics, s, icon, 0, 0, 10, 0, rectangle, rectangle2, rectangle3, this.textIconGap);
        this.tabPane.putClientProperty("html", null);
        int tabLabelShiftX = this.getTabLabelShiftX(n, tabIndex, b);
        int tabLabelShiftY = this.getTabLabelShiftY(n, tabIndex, b);
        rectangle2.x += tabLabelShiftX;
        rectangle2.y += tabLabelShiftY;
        rectangle3.x += tabLabelShiftX;
        rectangle3.y += tabLabelShiftY;
    }
    
    private void paintText(SynthContext synthContext, Graphics graphics, int n, Font font, FontMetrics fontMetrics, int n2, String s, Rectangle rectangle, boolean b) {
        graphics.setFont(font);
        View textViewForTab = this.getTextViewForTab(n2);
        if (textViewForTab != null) {
            textViewForTab.paint(graphics, rectangle);
        }
        else {
            int displayedMnemonicIndex = this.tabPane.getDisplayedMnemonicIndexAt(n2);
            graphics.setColor(synthContext.getStyle().getColor(synthContext, ColorType.TEXT_FOREGROUND));
            synthContext.getStyle().getGraphicsUtils(synthContext).paintText(synthContext, graphics, s, rectangle, displayedMnemonicIndex);
        }
    }
    
    private void paintContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2) {
        int width = this.tabPane.getWidth();
        int height = this.tabPane.getHeight();
        Insets insets = this.tabPane.getInsets();
        int left = insets.left;
        int top = insets.top;
        int width2 = width - insets.right - insets.left;
        int height2 = height - insets.top - insets.bottom;
        switch (n) {
            case 2: {
                left += this.calculateTabAreaWidth(n, this.runCount, this.maxTabWidth);
                width2 -= left - insets.left;
                break;
            }
            case 4: {
                width2 -= this.calculateTabAreaWidth(n, this.runCount, this.maxTabWidth);
                break;
            }
            case 3: {
                height2 -= this.calculateTabAreaHeight(n, this.runCount, this.maxTabHeight);
                break;
            }
            default: {
                top += this.calculateTabAreaHeight(n, this.runCount, this.maxTabHeight);
                height2 -= top - insets.top;
                break;
            }
        }
        SynthLookAndFeel.updateSubregion(synthContext, graphics, new Rectangle(left, top, width2, height2));
        synthContext.getPainter().paintTabbedPaneContentBackground(synthContext, graphics, left, top, width2, height2);
        synthContext.getPainter().paintTabbedPaneContentBorder(synthContext, graphics, left, top, width2, height2);
    }
    
    private void ensureCurrentLayout() {
        if (!this.tabPane.isValid()) {
            this.tabPane.validate();
        }
        if (!this.tabPane.isValid()) {
            ((BasicTabbedPaneUI.TabbedPaneLayout)this.tabPane.getLayout()).calculateLayoutInfo();
        }
    }
    
    @Override
    protected int calculateMaxTabHeight(int tabPlacement) {
        FontMetrics fontMetrics = this.getFontMetrics(this.tabContext.getStyle().getFont(this.tabContext));
        int tabCount = this.tabPane.getTabCount();
        int max = 0;
        int height = fontMetrics.getHeight();
        for (int i = 0; i < tabCount; ++i) {
            max = Math.max(this.calculateTabHeight(tabPlacement, i, height), max);
        }
        return max;
    }
    
    @Override
    protected int calculateTabWidth(int n, int n2, FontMetrics fontMetrics) {
        Icon iconForTab = this.getIconForTab(n2);
        Insets tabInsets = this.getTabInsets(n, n2);
        int n3 = tabInsets.left + tabInsets.right;
        Component tabComponent = this.tabPane.getTabComponentAt(n2);
        int n4;
        if (tabComponent != null) {
            n4 = n3 + tabComponent.getPreferredSize().width;
        }
        else {
            if (iconForTab != null) {
                n3 += iconForTab.getIconWidth() + this.textIconGap;
            }
            View textViewForTab = this.getTextViewForTab(n2);
            if (textViewForTab != null) {
                n4 = n3 + (int)textViewForTab.getPreferredSpan(0);
            }
            else {
                n4 = n3 + this.tabContext.getStyle().getGraphicsUtils(this.tabContext).computeStringWidth(this.tabContext, fontMetrics.getFont(), fontMetrics, this.tabPane.getTitleAt(n2));
            }
        }
        return n4;
    }
    
    @Override
    protected int calculateMaxTabWidth(int n) {
        FontMetrics fontMetrics = this.getFontMetrics(this.tabContext.getStyle().getFont(this.tabContext));
        int tabCount = this.tabPane.getTabCount();
        int max = 0;
        for (int i = 0; i < tabCount; ++i) {
            max = Math.max(this.calculateTabWidth(n, i, fontMetrics), max);
        }
        return max;
    }
    
    @Override
    protected Insets getTabInsets(int n, int n2) {
        this.updateTabContext(n2, false, false, false, this.getFocusIndex() == n2);
        return this.tabInsets;
    }
    
    @Override
    protected FontMetrics getFontMetrics() {
        return this.getFontMetrics(this.tabContext.getStyle().getFont(this.tabContext));
    }
    
    private FontMetrics getFontMetrics(Font font) {
        return this.tabPane.getFontMetrics(font);
    }
    
    private void updateTabContext(int index, boolean b, boolean b2, boolean b3, boolean b4) {
        int n = 0;
        int componentState;
        if (!this.tabPane.isEnabled() || !this.tabPane.isEnabledAt(index)) {
            componentState = (n | 0x8);
            if (b) {
                componentState |= 0x200;
            }
        }
        else if (b) {
            componentState = (n | 0x201);
            if (b3 && UIManager.getBoolean("TabbedPane.isTabRollover")) {
                componentState |= 0x2;
            }
        }
        else if (b3) {
            componentState = (n | 0x3);
        }
        else {
            componentState = (SynthLookAndFeel.getComponentState(this.tabPane) & 0xFFFFFEFF);
        }
        if (b4 && this.tabPane.hasFocus()) {
            componentState |= 0x100;
        }
        if (b2) {
            componentState |= 0x4;
        }
        this.tabContext.setComponentState(componentState);
    }
    
    @Override
    protected LayoutManager createLayoutManager() {
        if (this.tabPane.getTabLayoutPolicy() == 1) {
            return super.createLayoutManager();
        }
        return new BasicTabbedPaneUI.TabbedPaneLayout() {
            @Override
            public void calculateLayoutInfo() {
                super.calculateLayoutInfo();
                if (SynthTabbedPaneUI.this.tabOverlap != 0) {
                    int tabCount = SynthTabbedPaneUI.this.tabPane.getTabCount();
                    int leftToRight = SynthTabbedPaneUI.this.tabPane.getComponentOrientation().isLeftToRight();
                    for (int i = SynthTabbedPaneUI.this.runCount - 1; i >= 0; --i) {
                        int n = SynthTabbedPaneUI.this.tabRuns[i];
                        int n2 = SynthTabbedPaneUI.this.tabRuns[(i == SynthTabbedPaneUI.this.runCount - 1) ? 0 : (i + 1)];
                        int a;
                        int access$700;
                        Rectangle rectangle;
                        Rectangle rectangle2;
                        Rectangle rectangle3;
                        Rectangle rectangle4;
                        for (int n3 = (n2 != 0) ? (n2 - 1) : (tabCount - 1), j = n + 1; j <= n3; rectangle = SynthTabbedPaneUI.this.rects[j], rectangle.x += a, rectangle2 = SynthTabbedPaneUI.this.rects[j], rectangle2.y += access$700, rectangle3 = SynthTabbedPaneUI.this.rects[j], rectangle3.width += Math.abs(a), rectangle4 = SynthTabbedPaneUI.this.rects[j], rectangle4.height += Math.abs(access$700), ++j) {
                            a = 0;
                            access$700 = 0;
                            switch (SynthTabbedPaneUI.this.tabPane.getTabPlacement()) {
                                case 1:
                                case 3: {
                                    a = (leftToRight ? SynthTabbedPaneUI.this.tabOverlap : (-SynthTabbedPaneUI.this.tabOverlap));
                                    break;
                                }
                                case 2:
                                case 4: {
                                    access$700 = SynthTabbedPaneUI.this.tabOverlap;
                                    break;
                                }
                            }
                        }
                    }
                }
            }
        };
    }
    
    private class SynthScrollableTabButton extends SynthArrowButton implements UIResource
    {
        public SynthScrollableTabButton(int n) {
            super(n);
            this.setName("TabbedPane.button");
        }
    }
}
